==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DNewArrayExpr.h <==
// public class soot.dava.internal.javaRep.DNewArrayExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 137ce2d64c3fa885 soot_dava_internal_javaRep_DNewArrayExpr
// @dep_class cc0d5acb5fd5a93a soot_jimple_internal_AbstractNewArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewArrayExpr

#include "soot/jimple/internal/AbstractNewArrayExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNewArrayExpr_H_
#define _JC_soot_dava_internal_javaRep_DNewArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$refs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object	_jc_soot_dava_internal_javaRep_DNewArrayExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNewArrayExpr$method$_init$0b3348c37b519d7f(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *, struct _jc_soot_Type$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNewArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *);
extern jint _jc_soot_dava_internal_javaRep_DNewArrayExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DNewArrayExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *);
extern void _jc_soot_dava_internal_javaRep_DNewArrayExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewArrayExpr$vmethods	soot_jimple_internal_AbstractNewArrayExpr;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods	soot_dava_internal_javaRep_DNewArrayExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$refs {
    _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs	soot_dava_internal_javaRep_DNewArrayExpr;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_refs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs	soot_dava_internal_javaRep_DNewArrayExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object {
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype _jc_soot_dava_internal_javaRep_DNewArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNewArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNewArrayExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNewArrayExpr_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DNewArrayExpr.h <==
// public class soot.dava.internal.javaRep.DNewArrayExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 137ce2d64c3fa885 soot_dava_internal_javaRep_DNewArrayExpr
// @dep_class cc0d5acb5fd5a93a soot_jimple_internal_AbstractNewArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewArrayExpr

#include "soot/jimple/internal/AbstractNewArrayExpr.h"

#ifndef _JC_soot_dava_internal_javaRep_DNewArrayExpr_H_
#define _JC_soot_dava_internal_javaRep_DNewArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$refs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$refs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs	_jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object	_jc_soot_dava_internal_javaRep_DNewArrayExpr$object;

typedef const struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DNewArrayExpr$method$_init$0b3348c37b519d7f(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *, struct _jc_soot_Type$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_javaRep_DNewArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_dava_internal_javaRep_DNewArrayExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DNewArrayExpr$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_javaRep_DNewArrayExpr$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_javaRep_DNewArrayExpr$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewArrayExpr$vmethods	soot_jimple_internal_AbstractNewArrayExpr;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vmethods	soot_dava_internal_javaRep_DNewArrayExpr;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$refs {
    _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_refs	soot_dava_internal_javaRep_DNewArrayExpr;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_refs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_soot_dava_internal_javaRep_DNewArrayExpr$sub_nonrefs	soot_dava_internal_javaRep_DNewArrayExpr;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DNewArrayExpr$object {
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DNewArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DNewArrayExpr$vtype _jc_soot_dava_internal_javaRep_DNewArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DNewArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DNewArrayExpr$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DNewArrayExpr_H_ */
